@@ -27,6 +27,7 @@
 #include <math.h>
 #include <time.h>
 #include <gnome.h>
+#include <string.h>
 #include <gtk/gtk.h>
 #include <gconf/gconf-client.h>
 #include <bonobo-activation/bonobo-activation.h>
@@ -219,32 +220,49 @@ verb_HelpAbout_cb (BonoboUIComponent *uic, gpointer user_data, const char *cname
 {
 	static GtkWidget *about;
 	static const char *authors[] = {
-		"Federico Mena-Quintero",
-		"Martin Baulig",
-		"Arik Devens",
-		"Jens Finke",
-		"Michael Meeks",
-		"Lutz Mueller",
+		"Federico Mena-Quintero <federico@gnu.org>",
+		"Jens Finke <jens@triq.net>",
+		"Lutz Mueller <urc8@rz.uni-karlsruhe.de>",
+		"Martin Baulig <martin@home-of-linux.org>",
+		"Arik Devens <arik@gnome.org>",
+		"Michael Meeks <mmeeks@gnu.org>",
 		NULL
 	};
-	const char *translator_credits;
+	static const char *documenters[] = {
+		"Eliot Landrum <eliot@landrum.cx>",
+		"Sun GNOME Documentation Team <gdocteam@sun.com>",
+		"Federico Mena-Quintero <federico@gnu.org>",
+		NULL
+	};
+	const char *translators;
+
+
 
 	if (!about) {
+		GdkPixbuf *pixbuf;
+
 		/* Translators should localize the following string
-		 * which will be displayed at the bottom of the about
-		 * box to give credit to the translator(s).
+		 * which will give them credit in the About box.
+		 * E.g. "Fulano de Tal <fulano@detal.com>"
 		 */
-		translator_credits = _("Translator Credits");
+		translators = _("translator_credits-PLEASE_ADD_YOURSELF_HERE");
+
+		pixbuf = gdk_pixbuf_new_from_file (EOG_ICONDIR "/gnome-eog.png", NULL);
 
 		about = gnome_about_new (
 			_("Eye of Gnome"),
 			VERSION,
 			_("Copyright (C) 2000-2002 The Free Software Foundation"),
-			_("The GNOME image viewing and cataloging program"),
+			_("The GNOME image viewing and cataloging program."),
 			authors,
-			NULL, /* char **documentors */
-			translator_credits,
-			NULL);
+			documenters,
+			(strcmp (translators, "translator_credits-PLEASE_ADD_YOURSELF_HERE")
+			 ? translators : NULL),
+			pixbuf);
+
+		if (pixbuf)
+			g_object_unref (pixbuf);
+
 		g_signal_connect (about, "destroy",
 				  G_CALLBACK (gtk_widget_destroyed),
 				  &about);
@@ -255,10 +273,34 @@ verb_HelpAbout_cb (BonoboUIComponent *uic, gpointer user_data, const char *cname
 }
 
 static void
-verb_HelpContent_cb (BonoboUIComponent *uic, gpointer user_data, const char *cname)
+verb_HelpContent_cb (BonoboUIComponent *uic, gpointer data, const char *cname)
 {
-	GError *error = NULL;
-	gnome_help_display ("eog",NULL,&error);
+	GError *error;
+	EogWindow *window;
+
+	window = EOG_WINDOW (data);
+
+	error = NULL;
+	gnome_help_display ("eog", NULL, &error);
+
+	if (error) {
+		GtkWidget *dialog;
+
+		dialog = gtk_message_dialog_new (GTK_WINDOW (window),
+						 0,
+						 GTK_MESSAGE_ERROR,
+						 GTK_BUTTONS_CLOSE,
+						 _("Could not display help for Eye of Gnome.\n"
+						   "%s"),
+						 error->message);
+
+		g_signal_connect_swapped (dialog, "response",
+					  G_CALLBACK (gtk_widget_destroy),
+					  dialog);
+		gtk_widget_show (dialog);
+
+		g_error_free (error);
+	}
 }
 
 
@@ -597,7 +639,6 @@ GtkWidget *
 eog_window_new (void)
 {
 	EogWindow *window;
-	BonoboUIContainer *uic;
 
 	window = EOG_WINDOW (g_object_new (EOG_TYPE_WINDOW, "win_name", "eog", "title", _("Eye of Gnome"), NULL));
 
@@ -648,6 +689,7 @@ eog_window_construct (EogWindow *window)
 {
 	EogWindowPrivate *priv;
 	BonoboUIContainer *ui_container;
+	GtkWidget *widget;
 
 	g_return_if_fail (window != NULL);
 	g_return_if_fail (EOG_IS_WINDOW (window));
@@ -669,7 +711,7 @@ eog_window_construct (EogWindow *window)
 	bonobo_ui_component_set_container (priv->ui_comp, 
 					   BONOBO_OBJREF (ui_container), NULL);
 
-	bonobo_ui_util_set_ui (priv->ui_comp, NULL, "eog-shell-ui.xml", "EOG", NULL);
+	bonobo_ui_util_set_ui (priv->ui_comp, DATADIR, "eog-shell-ui.xml", "EOG", NULL);
 	bonobo_ui_component_add_verb_list_with_data (priv->ui_comp, eog_app_verbs, window);
 
 	/* add statusbar */
@@ -684,6 +726,13 @@ eog_window_construct (EogWindow *window)
 	g_signal_connect (G_OBJECT (priv->ctrl_frame), "activate_uri",
 			  (GtkSignalFunc) activate_uri_cb, NULL);
 
+	widget = bonobo_control_frame_get_widget (priv->ctrl_frame);
+	if (!widget)
+		g_assert_not_reached ();
+
+	gtk_box_pack_start (GTK_BOX (priv->box), widget, TRUE, TRUE, 0);
+	gtk_widget_show (widget);
+
 	set_drag_dest (window);
 
 	/* set default geometry */
@@ -813,7 +862,7 @@ check_for_control_properties (EogWindow *window)
 		g_free (title);
 		mask = g_strdup ("window/title");
 	} else {
-		g_warning (_("Control doesn't support window_title property."));
+		g_warning ("Control doesn't support window_title property.");
 		gtk_window_set_title (GTK_WINDOW (window), "Eye of Gnome");
 	}
 
@@ -829,7 +878,7 @@ check_for_control_properties (EogWindow *window)
 		g_free (mask);
 		mask = temp;
 	} else {
-		g_warning (_("Control doesn't support status_text property."));
+		g_warning ("Control doesn't support status_text property.");
 	}
 
 	/* register for further changes */
@@ -848,7 +897,7 @@ check_for_control_properties (EogWindow *window)
 	return;
 
 on_error:
-	g_warning (_("Control doesn't have properties"));
+	g_warning ("Control doesn't have properties");
 	gtk_window_set_title (GTK_WINDOW (window), "Eye of Gnome");
 }
 
@@ -865,7 +914,7 @@ get_viewer_control (GnomeVFSURI *uri, GnomeVFSFileInfo *info)
 	
 	/* check for valid mime_type */
 	if ((info->valid_fields & GNOME_VFS_FILE_INFO_FIELDS_MIME_TYPE) == 0) {
-		g_warning (_("Couldn't retrieve mime type for file."));
+		g_warning ("Couldn't retrieve mime type for file.");
 		return CORBA_OBJECT_NIL;
 	}
 
@@ -1026,7 +1075,6 @@ get_collection_control_list (GList *text_uri_list)
 static void 
 add_control_to_ui (EogWindow *window, Bonobo_Control control)
 {
-	GtkWidget *widget;
 	EogWindowPrivate *priv;
 	CORBA_Environment ev;
 	Bonobo_PropertyControl prop_control;
@@ -1036,17 +1084,8 @@ add_control_to_ui (EogWindow *window, Bonobo_Control control)
 	
 	priv = window->priv;
 	CORBA_exception_init (&ev);
-	
-	bonobo_control_frame_bind_to_control (priv->ctrl_frame, control, &ev);
-	widget = bonobo_control_frame_get_widget (priv->ctrl_frame);
-	
-	if (!widget) {
-	        g_warning ("Could not create a widget from the control!");
-		return;
-	}
-	gtk_container_add (GTK_CONTAINER (priv->box), widget);
-	gtk_widget_show (widget);
 
+	bonobo_control_frame_bind_to_control (priv->ctrl_frame, control, &ev);
 	bonobo_control_frame_control_activate (priv->ctrl_frame);
 
 	/* update sensitivity of the properties menu item */
@@ -1108,7 +1147,7 @@ eog_window_open (EogWindow *window, const char *text_uri)
 					      GNOME_VFS_FILE_INFO_FOLLOW_LINKS |
 					      GNOME_VFS_FILE_INFO_GET_MIME_TYPE);
 	if (result != GNOME_VFS_OK) {
-		g_warning (_("Error while obtaining file informations."));
+		g_warning ("Error while obtaining file informations.");
 		return FALSE;
 	}
 	
