@@ -11,6 +11,7 @@
  */
 #include <config.h>
 #include <stdio.h>
+#include <math.h>
 #include <gtk/gtksignal.h>
 #include <gtk/gtkmarshal.h>
 #include <gtk/gtktypeutils.h>
@@ -24,7 +25,6 @@ struct _EogControlPrivate {
 	EogImageView       *image_view;
 
 	BonoboZoomable     *zoomable;
-	float               zoom_level;
 	gboolean            has_zoomable_frame;
 };
 
@@ -33,8 +33,6 @@ static GObjectClass *eog_control_parent_class;
 static void
 eog_control_destroy (BonoboObject *object)
 {
-	EogControl *control;
-
 	g_return_if_fail (object != NULL);
 	g_return_if_fail (EOG_IS_CONTROL (object));
 
@@ -69,10 +67,11 @@ zoomable_set_frame_cb (BonoboZoomable *zoomable, EogControl *control)
 }
 
 static void
-zoomable_set_zoom_level_cb (BonoboZoomable *zoomable, float new_zoom_level,
+zoomable_set_zoom_level_cb (BonoboZoomable *zoomable, CORBA_float new_zoom_level,
 			    EogControl *control)
 {
 	EogControlPrivate *priv;
+	double zoomx, zoomy;
 
 	g_return_if_fail (control != NULL);
 	g_return_if_fail (EOG_IS_CONTROL (control));
@@ -80,67 +79,63 @@ zoomable_set_zoom_level_cb (BonoboZoomable *zoomable, float new_zoom_level,
 	priv = control->priv;
 
 	eog_image_view_set_zoom_factor (priv->image_view, new_zoom_level);
-	priv->zoom_level = eog_image_view_get_zoom_factor (priv->image_view);
-	bonobo_zoomable_report_zoom_level_changed (zoomable, priv->zoom_level, 
+
+	eog_image_view_get_zoom_factor (priv->image_view, &zoomx, &zoomy);
+	bonobo_zoomable_report_zoom_level_changed (zoomable, 
+						   sqrt (zoomx * zoomy),
 						   NULL);
 }
 
 static float preferred_zoom_levels[] = {
-	1.0 / 10.0, 1.0 / 9.0, 1.0 / 8.0, 1.0 / 7.0, 1.0 / 6.0,
-	1.0 / 5.0, 1.0 / 4.0, 1.0 / 3.0, 1.0 / 2.0, 1.0, 2.0,
-	3.0, 4.0, 5.0, 6.0, 7.0, 8.0, 9.0, 10.0
+	1.0 / 100, 1.0 / 50, 1.0 / 20,
+	1.0 / 10.0, 1.0 / 5.0, 1.0 / 3.0, 1.0 / 2.0, 1.0 / 1.5, 
+        1.0, 2.0, 3.0, 4.0, 5.0, 6.0, 7.0, 8.0, 9.0, 10.0,
+        11.0, 12.0, 13.0, 14.0, 15.0, 16.0, 17.0, 18.0, 19.0, 20.0
 };
 static const gchar *preferred_zoom_level_names[] = {
-	"1:10", "1:9", "1:8", "1:7", "1:6", "1:5", "1:4", "1:3",
-	"1:2", "1:1", "2:1", "3:1", "4:1", "5:1", "6:1", "7:1",
-	"8:1", "9:1", "10:1"
+	"1:100", "1:50", "1:20", "1:10", "1:5", "1:3", "1:2", "2:3",
+	"1:1", "2:1", "3:1", "4:1", "5:1", "6:1", "7:1",
+	"8:1", "9:1", "10:1", "11:1", "12:1", "13:1", "14:1", "15:1",
+	"16:1", "17:1", "18:1", "19:1", "20:1"
 };
 
-static const gint max_preferred_zoom_levels = (sizeof (preferred_zoom_levels) /
-					       sizeof (float)) - 1;
+static const gint n_zoom_levels = (sizeof (preferred_zoom_levels) / sizeof (float));
 
-static int
-zoom_index_from_float (float zoom_level)
-{
-	int i;
-
-	for (i = 0; i < max_preferred_zoom_levels; i++) {
-		float this, epsilon;
-
-		/* if we're close to a zoom level */
-		this = preferred_zoom_levels [i];
-		epsilon = this * 0.01;
-
-		if (zoom_level < this+epsilon)
-			return i;
-	}
-
-	return max_preferred_zoom_levels;
-}
-
-static float
+static double
 zoom_level_from_index (int index)
 {
-	if (index > max_preferred_zoom_levels)
-		index = max_preferred_zoom_levels;
-
-	return preferred_zoom_levels [index];
+	if (index >= 0 && index < n_zoom_levels)
+		return preferred_zoom_levels [index];
+	else
+		return 1.0;
 }
 
 static void
 zoomable_zoom_in_cb (BonoboZoomable *zoomable, EogControl *control)
 {
-	float new_zoom_level;
+	double zoomx, zoomy;
+	double zoom_level;
+	double new_zoom_level;
 	int index;
+	int i;
 
 	g_return_if_fail (control != NULL);
 	g_return_if_fail (EOG_IS_CONTROL (control));
 
-	index = zoom_index_from_float (control->priv->zoom_level);
-	if (index == max_preferred_zoom_levels)
-		return;
+	eog_image_view_get_zoom_factor (control->priv->image_view, &zoomx, &zoomy);
+	zoom_level = sqrt (zoomx * zoomy);
+	index = -1;
+
+	/* find next greater zoom level index */
+	for (i = 0; i < n_zoom_levels; i++) {
+		if (preferred_zoom_levels [i] > zoom_level) {
+			index = i;
+			break;
+		}
+	}
+
+	if (index == -1) return;
 
-	index++;
 	new_zoom_level = zoom_level_from_index (index);
 
 	g_signal_emit_by_name (G_OBJECT (zoomable), "set_zoom_level",
@@ -150,17 +145,28 @@ zoomable_zoom_in_cb (BonoboZoomable *zoomable, EogControl *control)
 static void
 zoomable_zoom_out_cb (BonoboZoomable *zoomable, EogControl *control)
 {
-	float new_zoom_level;
-	int index;
+	double zoomx, zoomy;
+	double zoom_level;
+	double new_zoom_level;
+	int index, i;
 
 	g_return_if_fail (control != NULL);
 	g_return_if_fail (EOG_IS_CONTROL (control));
 
-	index = zoom_index_from_float (control->priv->zoom_level);
-	if (index == 0)
+	eog_image_view_get_zoom_factor (control->priv->image_view, &zoomx, &zoomy);
+	zoom_level = sqrt (zoomx * zoomy);
+	index = -1;
+	
+	/* find next lower zoom level index */
+	for (i = n_zoom_levels - 1; i >= 0; i--) {
+		if (preferred_zoom_levels [i] < zoom_level) {
+			index = i;
+			break;
+		}
+	}
+	if (index == -1)
 		return;
 
-	index--;
 	new_zoom_level = zoom_level_from_index (index);
 
 	g_signal_emit_by_name (G_OBJECT (zoomable), "set_zoom_level",
@@ -170,14 +176,15 @@ zoomable_zoom_out_cb (BonoboZoomable *zoomable, EogControl *control)
 static void
 zoomable_zoom_to_fit_cb (BonoboZoomable *zoomable, EogControl *control)
 {
-	float new_zoom_level;
+	double zoomx, zoomy;
+	double new_zoom_level;
 
 	g_return_if_fail (control != NULL);
 	g_return_if_fail (EOG_IS_CONTROL (control));
 
 	eog_image_view_zoom_to_fit (control->priv->image_view, TRUE);
-	new_zoom_level = eog_image_view_get_zoom_factor
-		(control->priv->image_view);
+	eog_image_view_get_zoom_factor (control->priv->image_view, &zoomx, &zoomy);
+	new_zoom_level = sqrt (zoomx * zoomy);
 
 	g_signal_emit_by_name (G_OBJECT (zoomable), "set_zoom_level",
 			       new_zoom_level);
@@ -381,8 +388,6 @@ eog_control_construct (EogControl    *control,
 		return NULL;
 	}
 	widget = eog_image_view_get_widget (priv->image_view);
-	gtk_scrolled_window_set_shadow_type (GTK_SCROLLED_WINDOW (widget),
-					     GTK_SHADOW_IN);
 
 	bonobo_control_construct (BONOBO_CONTROL (control), widget);
 	
@@ -417,15 +422,14 @@ eog_control_construct (EogControl    *control,
 			  G_CALLBACK (zoomable_zoom_to_default_cb),
 			  control);
 
-	priv->zoom_level = 1.0;
 	bonobo_zoomable_set_parameters_full (priv->zoomable,
-					     priv->zoom_level,
+					     1.0,
 					     preferred_zoom_levels [0],
-					     preferred_zoom_levels [max_preferred_zoom_levels],
+					     preferred_zoom_levels [n_zoom_levels-1],
 					     TRUE, TRUE, TRUE,
 					     preferred_zoom_levels,
 					     preferred_zoom_level_names,
-					     max_preferred_zoom_levels + 1);
+					     n_zoom_levels);
 	bonobo_object_add_interface (BONOBO_OBJECT (control),
 				     BONOBO_OBJECT (priv->zoomable));
 
